==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Effect/soxr/translations/soxr_plugin_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="31"/>
        <source>SoX Resampler Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>About SoX Resampler Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Effect/soxr/translations/soxr_plugin_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="30"/>
        <source>SoX Resampler Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="51"/>
        <source>About SoX Resampler Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Написана от Илия Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Средно</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
